 /*
 * file      : fileselect.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>

#include "../libbasebuild/libbasebuild.h"
#include "../src/global.h"
#include "fileselect.h"



typedef struct {
	
	GtkWidget	*filechooserdialog;
	gboolean	 BoolIsFolder;
	void		(*Func_Extern) (gchar *string);
	
} VAR_DIALOG;

VAR_DIALOG	VarDialog = {
			NULL,
			FALSE,
			NULL
			};



// GESTION FILESELECT
// 
gboolean fileselect_on_filechooserdialog_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	// gint    Choice = GPOINTER_TO_INT(user_data);
	gtk_widget_destroy(VarDialog.filechooserdialog);
	VarDialog.filechooserdialog = NULL;
	return FALSE;
}
gboolean fileselect_on_filechooserdialog_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	// gint    Choice = GPOINTER_TO_INT(user_data);
	gtk_widget_destroy(VarDialog.filechooserdialog);
	VarDialog.filechooserdialog = NULL;
	return FALSE;
}
void fileselect_on_button_cancel_clicked (GtkButton *button, gpointer user_data)
{
	// gint    Choice = GPOINTER_TO_INT(user_data);
	gtk_widget_destroy(VarDialog.filechooserdialog);
	VarDialog.filechooserdialog = NULL;
}
void fileselect_on_button_ok_clicked (GtkButton *button, gpointer user_data)
{
	// gint    Choice = GPOINTER_TO_INT(user_data);
	gchar  *Path = NULL;
	
	if (VarDialog.Func_Extern) {
		if (VarDialog.BoolIsFolder == TRUE) {
			Path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (VarDialog.filechooserdialog));
		}
		else {
			Path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (VarDialog.filechooserdialog));
		}

		(*VarDialog.Func_Extern) (Path);
	
		g_free (Path);
		Path = NULL;
	}
	
	gtk_widget_destroy(VarDialog.filechooserdialog);
	VarDialog.filechooserdialog = NULL;
	VarDialog.Func_Extern = NULL;
}

// http://www.codase.com/search/call?name=gtk_file_chooser_dialog_new&start=10
//
void fileselect (gchar *Title, gboolean BoolIsFolder, void (*Func_Extern) (gchar *string), gchar *Path)
{
	GtkWidget	*button_cancel = NULL;
	GtkWidget	*button_ok = NULL;
	GtkFileFilter	*filter;

	if (VarDialog.filechooserdialog != NULL) {
		gdk_window_raise (VarDialog.filechooserdialog->window);
		return;
	}
	
	VarDialog.BoolIsFolder = BoolIsFolder;
	VarDialog.Func_Extern = Func_Extern;
	
	VarDialog.filechooserdialog = gtk_file_chooser_dialog_new ("Title",
							 NULL,
							 // GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
							 // GTK_FILE_CHOOSER_ACTION_OPEN,
							 BoolIsFolder ? GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER : GTK_FILE_CHOOSER_ACTION_OPEN,
							 NULL,
							 NULL);
	
	if (FALSE == BoolIsFolder) {
		filter = gtk_file_filter_new ();
		gtk_file_filter_add_pattern (filter, "*.glade");
		gtk_file_filter_add_pattern (filter, "*.GLADE");
		gtk_file_filter_set_name (filter, "*.glade *.GLADE");
		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (VarDialog.filechooserdialog), filter);
	}
	
	gtk_window_set_position (GTK_WINDOW (VarDialog.filechooserdialog), GTK_WIN_POS_CENTER);
	gtk_window_set_type_hint (GTK_WINDOW (VarDialog.filechooserdialog), GDK_WINDOW_TYPE_HINT_DIALOG);
	
	gtk_window_set_transient_for (GTK_WINDOW(VarDialog.filechooserdialog), GTK_WINDOW(WindMain));
	gtk_window_set_modal (GTK_WINDOW (VarDialog.filechooserdialog), TRUE);
	
	button_cancel = gtk_button_new_from_stock ("gtk-cancel");
	gtk_widget_show (button_cancel);
	gtk_dialog_add_action_widget (GTK_DIALOG (VarDialog.filechooserdialog), button_cancel, GTK_RESPONSE_CANCEL);
	GTK_WIDGET_SET_FLAGS (button_cancel, GTK_CAN_DEFAULT);

	button_ok = gtk_button_new_from_stock ("gtk-open");
	gtk_widget_show (button_ok);
	gtk_dialog_add_action_widget (GTK_DIALOG (VarDialog.filechooserdialog), button_ok, GTK_RESPONSE_OK);
	GTK_WIDGET_SET_FLAGS (button_ok, GTK_CAN_DEFAULT);
	
	g_signal_connect ((gpointer) VarDialog.filechooserdialog, "delete_event", G_CALLBACK (fileselect_on_filechooserdialog_delete_event), (gpointer)NULL);
	g_signal_connect ((gpointer) VarDialog.filechooserdialog, "destroy_event", G_CALLBACK (fileselect_on_filechooserdialog_destroy_event), (gpointer)NULL);
	g_signal_connect ((gpointer) button_cancel, "clicked", G_CALLBACK (fileselect_on_button_cancel_clicked), (gpointer)NULL);
	g_signal_connect ((gpointer) button_ok, "clicked", G_CALLBACK (fileselect_on_button_ok_clicked), (gpointer)NULL);
	
	GLADE_HOOKUP_OBJECT_NO_REF (VarDialog.filechooserdialog, VarDialog.filechooserdialog, "filechooserdialog");
	GLADE_HOOKUP_OBJECT (VarDialog.filechooserdialog, button_cancel, "button_cancel");
	GLADE_HOOKUP_OBJECT (VarDialog.filechooserdialog, button_ok, "button_ok");

	gtk_widget_grab_default (button_ok);
	
	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (VarDialog.filechooserdialog), Path);
	
	libutils_set_default_icone_to_win (VarDialog.filechooserdialog);
	
  	gtk_widget_show (VarDialog.filechooserdialog);
}
















