 /*
 * file      : proto.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include "global.h"
#include "../libbasebuild/libbasebuild.h"
#include "build.h"
#include "proto.h"



typedef enum {
	SIGNAL_NONE = 0,
	SIGNAL_ACTIVATE,		// signal name="activate"
	SIGNAL_BUTTON_PRESS_EVENT,	// signal name="button_press_event"
	SIGNAL_BUTTON_RELEASE_EVENT,	// signal name="button_release_event"
	SIGNAL_CHANGED,			// signal name="changed"
	SIGNAL_CLICKED,			// signal name="clicked"
	SIGNAL_CLOSE,			// signal name="close"
	SIGNAL_DELETE_EVENT,		// signal name="delete_event"
	SIGNAL_DESTROY_EVENT,		// signal name="destroy_event"
	SIGNAL_DESTROY,			// signal name="destroy"
	SIGNAL_ENTER_NOTIFY_EVENT,	// signal name="enter_notify_event"
	SIGNAL_EVENT,			// signal name="event"
	SIGNAL_EVENT_AFTER,		// signal name="event_after"
	SIGNAL_EXPOSE_EVENT,		// signal name="expose_event"
	SIGNAL_KEY_PRESS_EVENT,		// signal name="key_press_event"
	SIGNAL_LEAVE_NOTIFY_EVENT,	// signal name="leave_notify_event"
	SIGNAL_MAP_EVENT,		// signal name="map_event"
	SIGNAL_REALIZE,			// signal name="realize"
	SIGNAL_RESPONSE,		// signal name="response"
	SIGNAL_DRAGNDROP_RECEVEID,	// signal name="drag_data_received"
	SIGNAL_TOGGLED,			// class="toggled"
	SIGNAL_SWITCH_PAGE,		// signal name="switch_page"
	SIGNAL_VALUE_CHANGED		// signal name="value_changed"
} TYPE_SIGNAL;

typedef struct {
	gchar		*Signal;	// ACTIVATE | CHANGED ...
	gchar		*Handler;	// Nom du handler
	TYPE_SIGNAL	TypeSignal;	// 
} STRUCT_SIGNAL;


typedef enum {
	CLASS_NONE = 0,
	CLASS_GTK_ALIGMENT,		// class="GtkAlignment"
	CLASS_GTK_BUTTON,		// class="GtkButton"
	CLASS_GTK_CHECKBUTTON,		// class="GtkCheckButton"
	CLASS_GTK_COMBOBOX,		// class="GtkComboBox"
	CLASS_GTK_COMBOBOXENTRY,	// class="GtkComboBoxEntry"
	CLASS_GTK_DIALOG,		// class="GtkDialog"
	CLASS_GTK_ENTRY,		// class="GtkEntry"
	CLASS_GTK_EVENTBOX,		// class="GtkEventBox"
	CLASS_GTK_EXPANDER,		// class="GtkExpander"
	CLASS_GTK_IMAGE,		// class="GtkImage"
	CLASS_GTK_IMAGEMENUITEM,	// class="GtkImageMenuItem"
	CLASS_GTK_FRAME,		// class="GtkFrame"
	CLASS_GTK_HBOX,			// class="GtkHBox"
	CLASS_GTK_LABEL,		// class="GtkLabel"
	CLASS_GTK_LINKBUTTON,		// class="GtkLinkButton"
	CLASS_GTK_MENUBAR,		// class="GtkMenuBar"
	CLASS_GTK_MENUITEM,		// class="GtkMenuItem"
	CLASS_GTK_MENU,			// class="GtkMenu"
	CLASS_GTK_NOTEBOOK,		// class="GtkNotebook"
	CLASS_GTK_PROGRESSBAR,		// class="GtkProgressBar"
	CLASS_GTK_RADIOBUTTON,		// class="GtkRadioButton"
	CLASS_GTK_SEPARATORMENUITEM,	// class="GtkSeparatorMenuItem"
	CLASS_GTK_SCROLLEWINDOW,	// class="GtkScrolledWindow"
	CLASS_GTK_SPINBUTTON,		// class="GtkSpinButton"
	CLASS_GTK_TABLE,		// class="GtkTable"
	CLASS_GTK_TEXTVIEW,		// class="GtkTextView"
	CLASS_GTK_TOGGLEBUTTON,		// class="GtkToggleButton"
	CLASS_GTK_VBOX,			// class="GtkVBox"
	CLASS_GTK_VIEWPORT,		// class="GtkViewport"
	CLASS_GTK_WINDOW		// class="GtkWindow"
} TYPE_CLASS;

typedef struct {
	gchar		*Object;	// GTK_BUTTON | GTK_WINDOW ...
	gchar		*Id;		// Nom de l' Id
	TYPE_CLASS	TypeClass;	// 
	GList		*ListSignal;	// LISTE DE STRUCT_SIGNAL POUR STRUCT_CLASS
} STRUCT_CLASS;

GList	*ListClass = NULL;	// LISTE DES 'STRUCT_CLASS'

/*
	EXAMPLE WITH NEW VERSION OF GLADE:
	----------------------------------
	<object class="GtkWindow" id="window_main">
		<signal name="delete_event" handler="on_window_main_delete_event"/>
	<object class="GtkImageMenuItem" id="imagemenuitem_quit">
		<signal name="activate" handler="on_imagemenuitem_quit_activate"/>
	<object class="GtkButton" id="button_path_projet">
		<signal name="clicked" handler="on_button_path_projet_clicked"/>
		<signal name="realize" handler="on_button_path_projet_realize"/>
	<object class="GtkAboutDialog" id="aboutdialog_basebuild">
		<signal name="destroy_event" handler="on_aboutdialog_basebuild_destroy_event"/>
		<signal name="response" handler="on_aboutdialog_basebuild_response"/>
		<signal name="delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
*/


typedef struct {
	GString		*GstrMain;
	GString		*GstrTranslate;
	gboolean	BoolTranslateOk;
	gchar		*PathNameFileGlade;
	gboolean	BoolOk;
} VAR_PROTO;

VAR_PROTO VarProto = {
		NULL,	// GstrMain
		NULL,	// GstrTranslate
		FALSE,	// BoolTranslateOk
		NULL,	// PathNameFileGlade
		FALSE	// BoolOk
		};
/*
GString	*GstrPot = NULL;
GstrPot = g_string_new (NULL);
g_string_append_printf (GstrPot, "%s/main.c\n", VarSrc->Name);
g_string_free (GstrPot, TRUE);
*/



// 
// 
TYPE_CLASS Proto_get_type_class (gchar *p_NameClass)
{
	if (!strcmp(p_NameClass, "GtkAlignment"))		return (CLASS_GTK_ALIGMENT);
	else if (!strcmp(p_NameClass, "GtkButton"))		return (CLASS_GTK_BUTTON);
	else if (!strcmp(p_NameClass, "GtkCheckButton"))	return (CLASS_GTK_CHECKBUTTON);
	else if (!strcmp(p_NameClass, "GtkComboBox"))		return (CLASS_GTK_COMBOBOX);
	else if (!strcmp(p_NameClass, "GtkComboBoxEntry"))	return (CLASS_GTK_COMBOBOXENTRY);
	else if (!strcmp(p_NameClass, "GtkDialog"))		return (CLASS_GTK_DIALOG);
	else if (!strcmp(p_NameClass, "GtkEntry"))		return (CLASS_GTK_ENTRY);
	else if (!strcmp(p_NameClass, "GtkEventBox"))		return (CLASS_GTK_EVENTBOX);
	else if (!strcmp(p_NameClass, "GtkExpander"))		return (CLASS_GTK_EXPANDER);
	else if (!strcmp(p_NameClass, "GtkImage"))		return (CLASS_GTK_IMAGE);
	else if (!strcmp(p_NameClass, "GtkImageMenuItem"))	return (CLASS_GTK_IMAGEMENUITEM);
	else if (!strcmp(p_NameClass, "GtkFrame"))		return (CLASS_GTK_FRAME);
	else if (!strcmp(p_NameClass, "GtkHBox"))		return (CLASS_GTK_HBOX);
	else if (!strcmp(p_NameClass, "GtkLabel"))		return (CLASS_GTK_LABEL);
	else if (!strcmp(p_NameClass, "GtkLinkButton"))		return (CLASS_GTK_LINKBUTTON);
	else if (!strcmp(p_NameClass, "GtkMenuBar"))		return (CLASS_GTK_MENUBAR);
	else if (!strcmp(p_NameClass, "GtkMenuItem"))		return (CLASS_GTK_MENUITEM);
	else if (!strcmp(p_NameClass, "GtkMenu"))		return (CLASS_GTK_MENU);
	else if (!strcmp(p_NameClass, "GtkNotebook"))		return (CLASS_GTK_NOTEBOOK);
	else if (!strcmp(p_NameClass, "GtkProgressBar"))	return (CLASS_GTK_PROGRESSBAR);
	else if (!strcmp(p_NameClass, "GtkRadioButton"))	return (CLASS_GTK_RADIOBUTTON);
	else if (!strcmp(p_NameClass, "GtkSeparatorMenuItem"))	return (CLASS_GTK_SEPARATORMENUITEM);
	else if (!strcmp(p_NameClass, "GtkScrolledWindow"))	return (CLASS_GTK_SCROLLEWINDOW);
	else if (!strcmp(p_NameClass, "GtkSpinButton"))		return (CLASS_GTK_SPINBUTTON);
	else if (!strcmp(p_NameClass, "GtkTable"))		return (CLASS_GTK_TABLE);
	else if (!strcmp(p_NameClass, "GtkTextView"))		return (CLASS_GTK_TEXTVIEW);
	else if (!strcmp(p_NameClass, "GtkToggleButton"))	return (CLASS_GTK_TOGGLEBUTTON);
	else if (!strcmp(p_NameClass, "GtkVBox"))		return (CLASS_GTK_VBOX);
	else if (!strcmp(p_NameClass, "GtkViewport"))		return (CLASS_GTK_VIEWPORT);
	else if (!strcmp(p_NameClass, "GtkWindow"))		return (CLASS_GTK_WINDOW);
	
	return (CLASS_NONE);
}
// 
// 
TYPE_SIGNAL Proto_get_type_signal (gchar *p_NameSignal)
{
	if (!strcmp(p_NameSignal, "activate"))			return (SIGNAL_ACTIVATE);
	else if (!strcmp(p_NameSignal, "button_press_event"))	return (SIGNAL_BUTTON_PRESS_EVENT);
	else if (!strcmp(p_NameSignal, "button_release_event"))	return (SIGNAL_BUTTON_RELEASE_EVENT);
	else if (!strcmp(p_NameSignal, "changed"))		return (SIGNAL_CHANGED);
	else if (!strcmp(p_NameSignal, "clicked"))		return (SIGNAL_CLICKED);
	else if (!strcmp(p_NameSignal, "close"))		return (SIGNAL_CLOSE);
	else if (!strcmp(p_NameSignal, "delete_event"))		return (SIGNAL_DELETE_EVENT);
	else if (!strcmp(p_NameSignal, "destroy_event"))	return (SIGNAL_DESTROY_EVENT);
	else if (!strcmp(p_NameSignal, "destroy"))		return (SIGNAL_DESTROY);
	else if (!strcmp(p_NameSignal, "enter_notify_event"))	return (SIGNAL_ENTER_NOTIFY_EVENT);
	else if (!strcmp(p_NameSignal, "event"))		return (SIGNAL_EVENT);
	else if (!strcmp(p_NameSignal, "event_after"))		return (SIGNAL_EVENT_AFTER);
	else if (!strcmp(p_NameSignal, "expose_event"))		return (SIGNAL_EXPOSE_EVENT);
	else if (!strcmp(p_NameSignal, "key_press_event"))	return (SIGNAL_KEY_PRESS_EVENT);
	else if (!strcmp(p_NameSignal, "leave_notify_event"))	return (SIGNAL_LEAVE_NOTIFY_EVENT);
	else if (!strcmp(p_NameSignal, "map_event"))		return (SIGNAL_MAP_EVENT);
	else if (!strcmp(p_NameSignal, "realize"))		return (SIGNAL_REALIZE);
	else if (!strcmp(p_NameSignal, "response"))		return (SIGNAL_RESPONSE);
	else if (!strcmp(p_NameSignal, "drag_data_received"))	return (SIGNAL_DRAGNDROP_RECEVEID);
	else if (!strcmp(p_NameSignal, "toggled"))		return (SIGNAL_TOGGLED);
	else if (!strcmp(p_NameSignal, "switch_page"))		return (SIGNAL_SWITCH_PAGE);
	else if (!strcmp(p_NameSignal, "value_changed"))	return (SIGNAL_VALUE_CHANGED);
	
	return (SIGNAL_NONE);
}
// 
// 
gboolean Proto_alloc_object (gchar *p_str_object)
{
	STRUCT_CLASS	*StructClass = NULL;
	gchar		*PtrBegin = NULL;
	
	// PRINT_FUNC_LF();
	
	// <object class="GtkWindow" id="window_main">
	
	if (NULL == (StructClass = (STRUCT_CLASS *)g_malloc0 (sizeof (STRUCT_CLASS)))) {
		g_print ("ERREUR ALLOCATION POUR CLASS !!!\n");
		return FALSE;
	}
	
	// <object class="GtkWindow" id="window_main">
	// GtkWindow" id="window_main">
	
	PtrBegin = strchr (p_str_object, '"');
	PtrBegin ++;
	StructClass->Object = g_strdup (PtrBegin);
	PtrBegin = strchr (StructClass->Object, '"');
	*PtrBegin = '\0';
	
	// GET TYPE OF CLASSE
	StructClass->TypeClass = Proto_get_type_class (StructClass->Object);

	// <object class="GtkWindow" id="window_main">
	// window_main">
	
	PtrBegin = strstr (p_str_object, "id=");
	PtrBegin = strchr (PtrBegin, '"');
	PtrBegin ++;
	StructClass->Id     = g_strdup (PtrBegin);
	PtrBegin = strchr (StructClass->Id, '"');
	*PtrBegin = '\0';
	
	// SET ALLOCATE TO GLIST
	ListClass = g_list_append (ListClass, StructClass);
	
	return TRUE;
}
// 
// 
gboolean Proto_is_dupplicate (gchar *Str)
{
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {
					if (0 == strcmp (StructSignal->Handler, Str)) {
						// g_print (" -> DUPPLICATE IS -> %s\n", Str);
						return (TRUE);
					}
				}
				ListS = g_list_next (ListS);
			}
		}
		ListC = g_list_next (ListC);
	}
	return (FALSE);
}
// 
// 
gboolean Proto_alloc_signal (gchar *p_str_signal)
{
	STRUCT_SIGNAL	*StructSignal = NULL;
	GList		*List = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	gchar		*PtrBegin = NULL;
	
	// PRINT_FUNC_LF();
	
	// <signal name="delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	
	if (NULL == (StructSignal = (STRUCT_SIGNAL *)g_malloc0 (sizeof (STRUCT_SIGNAL)))) {
		g_print ("ERREUR ALLOCATION POUR SIGNAL !!!\n");
		return FALSE;
	}
	
	// <signal name="delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	// delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	
	PtrBegin = strchr (p_str_signal, '"');
	PtrBegin ++;
	StructSignal->Signal  = g_strdup (PtrBegin);
	PtrBegin = strchr (StructSignal->Signal, '"');
	*PtrBegin = '\0';
	
	// GET TYPE OF SIGNAL
	StructSignal->TypeSignal = Proto_get_type_signal (StructSignal->Signal);

	// <signal name="delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	// on_aboutdialog_basebuild_delete_event"/>
	
	PtrBegin = strstr (p_str_signal, "handler=");
	PtrBegin = strchr (PtrBegin, '"');
	PtrBegin ++;
	StructSignal->Handler = g_strdup (PtrBegin);
	PtrBegin = strchr (StructSignal->Handler, '"');
	*PtrBegin = '\0';
	
	// SEARCH GLIST
	List =  g_list_last (ListClass);
	StructClass = (STRUCT_CLASS *)List->data;
	
	// DUPPLICATE ?
	if (TRUE == Proto_is_dupplicate (StructSignal->Handler)) {
		g_free (StructSignal->Signal);
		g_free (StructSignal->Handler);
		g_free (StructSignal);
		StructSignal = NULL;
	}
	// SET ALLOCATE TO GLIST
	else {
		StructClass->ListSignal = g_list_last (StructClass->ListSignal);
		StructClass->ListSignal = g_list_append (StructClass->ListSignal, StructSignal);
	}
	return TRUE;
}
// 
// 
void Proto_alloc_translate_end (void)
{
	GString	*GstrTranslate = NULL;
	
	if (NULL != (GstrTranslate = Proto_get_buf_translate ())) {
		
		gchar	*Ptr = GstrTranslate->str;
		
		while (*Ptr) Ptr ++;
		while (*Ptr != ',') Ptr --;
		*Ptr = '\n';
		g_string_append_printf (VarProto.GstrTranslate, "};\n");
		g_string_append_printf (VarProto.GstrTranslate, "\tif (*trans [ 0 ] . string);\n");
		g_string_append_printf (VarProto.GstrTranslate, "}\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
		GstrTranslate = NULL;
	}
}
// 
// 
gboolean Proto_alloc_translate (gchar *p_str_translate)
{
/*
	<property name="label" translatable="yes">
&lt;b&gt;&lt;i&gt;Pour installer les programmes externes requis,
veuillez utiliser l'installateur de votre distribution Gnu/Linux.&lt;/i&gt;&lt;/b&gt;
</property>
	
	<property name="label" translatable="yes">&lt;b&gt; Informations &lt;/b&gt;</property>
        
        <col id="0" translatable="yes">Video - Theora + Vorbis (OGG)</col>

*/
	gchar	*Ptr = NULL;
	gchar	*PtrEnd = NULL;
	
	// g_print("SIGNAL_translatable  %s\n", p_str_translate);
	
	VarProto.BoolTranslateOk = TRUE;
		
	// CHERCHE LE POINTEUR DE DEBUT: Ptr
	if (NULL != (Ptr = strstr (p_str_translate, "translatable="))) {
		// RECHERCHE DE:   ">
		while (*Ptr != '>') Ptr ++;
		Ptr ++;
		g_print("{ _(\"");
		g_string_append_printf (VarProto.GstrTranslate, "{ _(\"");
	}
	else {
		// SINON Ptr POINTE AU DEBUT DE LA CHAINE
		Ptr = p_str_translate;
	}
	// CHERCHE LE POINTEUR DE FIN: PtrEnd
	// if (NULL != (PtrEnd = strstr (Ptr, "</property>"))) {
	if (NULL != (PtrEnd = strstr (Ptr, "</"))) {
		// AFFICHE DEPUIS: Ptr JUSQU'A: PtrEnd
		while (Ptr < PtrEnd) {
			if (*Ptr == '"') {
				g_print("\\\"");
				g_string_append_printf (VarProto.GstrTranslate, "\\\"");
			}
			else {
				g_print("%c", *Ptr);
				g_string_append_printf (VarProto.GstrTranslate, "%c", *Ptr);
			}
			Ptr ++;
		}
		// g_print ("\n");
		// MARQUE LA FIN DE LA RECHERCHE
		VarProto.BoolTranslateOk = FALSE;
		g_print("\") },\n");
		g_string_append_printf (VarProto.GstrTranslate, "\") },\n");
	}
	else {
		// AFFICHE DEPUIS: Ptr JUSQU'A LA FIN DE LA CHAINE
		while (*Ptr) {
			if (*Ptr == '"') {
				g_print("\\\"");
				g_string_append_printf (VarProto.GstrTranslate, "\\\"");
			}
			else {
				g_print("%c", *Ptr);
				g_string_append_printf (VarProto.GstrTranslate, "%c", *Ptr);
			}
			Ptr ++;
		}
		// g_print("%s", Ptr);
		// g_string_append_printf (VarProto.GstrTranslate, "%s", Ptr);
		// CR_LF DE FIN DE CHAINE
		g_print("\\n");
		g_string_append_printf (VarProto.GstrTranslate, "\\n");
	}
	
	return TRUE;
}
// 
// 
void Proto_print (void)
{
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	
	PRINT_FUNC_LF();
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
			g_print ("StructClass->Object = %s     ", StructClass->Object);
			g_print ("StructClass->Id = %s", StructClass->Id);
			g_print ("\n");
			
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {
					g_print ("StructSignal->Signal = %s     ", StructSignal->Signal);
					g_print ("StructSignal->Handler = %s", StructSignal->Handler);
					g_print ("\n");
				}
				ListS = g_list_next (ListS);
			}
		}
		ListC = g_list_next (ListC);
	}
	g_print ("\n");
}
// 
// 
void Proto_remove (void)
{
	// g_list_free (New);
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	gint		NbrClass = 0;
	gint		NbrSignal = 0;
	
	PRINT_FUNC_LF();
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {
					g_free (StructSignal->Signal);
					g_free (StructSignal->Handler);
					g_free (StructSignal);
					StructSignal = ListS->data = NULL;
					
					NbrSignal ++;
				}
				ListS = g_list_next (ListS);
			}
			g_list_free (StructClass->ListSignal);
			StructClass->ListSignal = NULL;
			
			g_free (StructClass->Object);
			g_free (StructClass->Id);
			g_free (StructClass);
			StructClass = ListC->data = NULL;
			
			NbrClass ++;
		}
		ListC = g_list_next (ListC);
	}
	g_list_free (ListClass);
	ListClass = NULL;
	
	g_print ("\tRemove NbrClass  = %d\n", NbrClass);
	g_print ("\tRemove NbrSignal = %d\n", NbrSignal);
	g_print ("\n");

	g_print ("VarProto.GstrMain = %p\n", VarProto.GstrMain);
	if (NULL != VarProto.GstrMain) {
		g_print ("\tFREE -> VarProto.GstrMain\n");
		g_string_free (VarProto.GstrMain, TRUE);
		VarProto.GstrMain = NULL;
		g_print ("\tVarProto.GstrMain = %p\n", VarProto.GstrMain);
	}
	g_print ("VarProto.GstrTranslate = %p\n", VarProto.GstrTranslate);
	if (NULL != VarProto.GstrTranslate) {
		g_print ("\tFREE -> VarProto.GstrTranslate\n");
		g_string_free (VarProto.GstrTranslate, TRUE);
		VarProto.GstrTranslate = NULL;
		g_print ("\tVarProto.GstrTranslate = %p\n", VarProto.GstrTranslate);
	}
	if (NULL != VarProto.PathNameFileGlade) {
		g_free (VarProto.PathNameFileGlade);
		VarProto.PathNameFileGlade = NULL;
	}
	VarProto.BoolOk = FALSE;
	VarProto.BoolTranslateOk = FALSE;
}
// 
// 
void Proto_make (void)
{
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	gchar		*StrClassGtkWindow = NULL;
	
	PRINT_FUNC_LF();
	
	VarProto.GstrMain = g_string_new (NULL);
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
					 	
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {
					
					switch (StructClass->TypeClass) {
						case CLASS_NONE :			// A DEFINIR
							g_string_append_printf (VarProto.GstrMain, "// [ CLASS UNDEFINED ] StructSignal->Signal = %s   Object = %s   Handler = %s\n", StructSignal->Signal, StructClass->Object, StructSignal->Handler);
							break;
						case CLASS_GTK_ALIGMENT :		// class="GtkAlignment"
							// g_print ("UNDEFINED : CLASS_GTK_ALIGMENT : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_ALIGMENT : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							break;
						case CLASS_GTK_BUTTON :			// class="GtkButton"
							if (StructSignal->TypeSignal == SIGNAL_ENTER_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_LEAVE_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_CLICKED) {
								// g_print ("void %s (GtkButton *button, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkButton *button, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_BUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_BUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}							
							break;
						case CLASS_GTK_CHECKBUTTON :		// class="GtkCheckButton"
							if (StructSignal->TypeSignal == SIGNAL_CLICKED) {	
								// g_print ("void %s (GtkButton *button, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkButton *button, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_ENTER_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_LEAVE_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_TOGGLED) {
								// g_print ("void %s (GtkToggleButton *togglebutton, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkToggleButton *togglebutton, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_CHECKBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_CHECKBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_COMBOBOX :		// class="GtkComboBox"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_CHANGED) {
								// g_print ("void %s (GtkComboBox *combobox, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkComboBox *combobox, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_COMBOBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_COMBOBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_COMBOBOXENTRY :		// class="GtkComboBoxEntry"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_CHANGED) {
								// g_print ("void %s (GtkComboBox *combobox, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkComboBox *combobox, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_COMBOBOXENTRY : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_COMBOBOXENTRY : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_DIALOG :			// class="GtkDialog"
							if (StructSignal->TypeSignal == SIGNAL_DELETE_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_DESTROY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							
							
							} else if (StructSignal->TypeSignal == SIGNAL_CLOSE) {
								// close
								// g_print ("void %s (GtkDialog *Dialog, gpointer data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkDialog *Dialog, gpointer data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_MAP_EVENT) {
								// map_event
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_RESPONSE) {
								// response
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_DIALOG : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_DIALOG : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_ENTRY :			// class="GtkEntry"
							if (StructSignal->TypeSignal == SIGNAL_CHANGED) {
								// g_print ("void %s (GtkEditable *editable, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkEditable *editable, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_ACTIVATE) {
								// g_print ("void %s (GtkEntry *editable, gpointer data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkEntry *editable, gpointer data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_ENTRY : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_ENTRY : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_EVENTBOX	 :		// class="GtkEventBox"
							if (StructSignal->TypeSignal == SIGNAL_ENTER_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_LEAVE_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_EVENT_AFTER) {
								// g_print ("void %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_EXPOSE_EVENT) {
								// g_print ("gboolean %s GtkWidget *widget, GdkEventExpose *event, gpointer user_data);\n", StructSignal->Handler);							
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventExpose *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_EVENTBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_EVENTBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_EXPANDER :		// class="GtkExpander"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_EXPANDER : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_EXPANDER : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_IMAGE :			// class="GtkImage"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_IMAGE : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_IMAGE : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_IMAGEMENUITEM :		// class="GtkImageMenuItem"
							if (StructSignal->TypeSignal == SIGNAL_ACTIVATE) {
								// g_print ("void %s (GtkImageMenuItem *menuitem, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkImageMenuItem *menuitem, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_IMAGEMENUITEM : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_IMAGEMENUITEM : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_FRAME :			// class="GtkFrame"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_FRAME : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_FRAME : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_HBOX :			// class="GtkHBox"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_HBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_HBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_LABEL :			// class="GtkLabel"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_LABEL : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_LABEL : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_LINKBUTTON :		// class="GtkLinkButton"
							if (StructSignal->TypeSignal == SIGNAL_CLICKED) {
								// g_print ("void %s (GtkLinkButton *button, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkLinkButton *button, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_LINKBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_LINKBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_MENUBAR :		// class="GtkMenuBar"
							// g_print ("UNDEFINED : CLASS_GTK_MENUBAR : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_MENUBAR : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							break;
						case CLASS_GTK_MENUITEM :		// class="GtkMenuItem"
							if (StructSignal->TypeSignal == SIGNAL_ACTIVATE) {
								// g_print ("void %s (GtkMenuItem *menuitem, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkMenuItem *menuitem, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_MENUITEM : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_MENUITEM : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_MENU :			// class="GtkMenu"
							// g_print ("UNDEFINED : CLASS_GTK_MENU : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_MENU : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							break;
						case CLASS_GTK_NOTEBOOK :		// class="GtkNotebook"
							if (StructSignal->TypeSignal == SIGNAL_SWITCH_PAGE) {
								// g_print ("void %s (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_NOTEBOOK : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_NOTEBOOK : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_PROGRESSBAR :		// class="GtkProgressBar"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_PROGRESSBAR : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_PROGRESSBAR : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_RADIOBUTTON :		// class="GtkRadioButton"
							if (StructSignal->TypeSignal == SIGNAL_CLICKED) {	
								// g_print ("void %s (GtkButton *button, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkButton *button, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_TOGGLED) {
								// g_print ("void %s (GtkToggleButton *togglebutton, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkToggleButton *togglebutton, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_RADIOBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_RADIOBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_SEPARATORMENUITEM :	// class="GtkSeparatorMenuItem"
							// g_print ("UNDEFINED : CLASS_GTK_SEPARATORMENUITEM : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_SEPARATORMENUITEM : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							break;
						case CLASS_GTK_SCROLLEWINDOW :		// class="GtkScrolledWindow"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_SCROLLEWINDOW : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_SCROLLEWINDOW : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_SPINBUTTON :		// class="GtkSpinButton"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_CHANGED) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_VALUE_CHANGED) {
								// g_print ("void %s (GtkSpinButton *spinbutton, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkSpinButton *spinbutton, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_BUTTON_PRESS_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventButton *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventButton *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_BUTTON_RELEASE_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventButton *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventButton *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_SPINBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_SPINBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_TABLE :			// class="GtkTable"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_TABLE : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_TABLE : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_TEXTVIEW :		// class="GtkTextView"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_DRAGNDROP_RECEVEID) {
								// g_print ("void %s (GtkWidget *widget, GdkDragContext *drag_context, gint x, gint y, GtkSelectionData *data, guint info, guint time, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, GdkDragContext *drag_context, gint x, gint y, GtkSelectionData *data, guint info, guint time, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_KEY_PRESS_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventKey *event, gpointer user_data;\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventKey *event, gpointer user_data\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_TEXTVIEW : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_TEXTVIEW : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_TOGGLEBUTTON :		// class="GtkToggleButton"
							if (StructSignal->TypeSignal == SIGNAL_ENTER_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_LEAVE_NOTIFY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_CLICKED) {
								// g_print ("void %s (GtkButton *button, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkButton *button, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_TOGGLEBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_TOGGLEBUTTON : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_VBOX :			// class="GtkVBox"
							// g_print ("UNDEFINED : CLASS_GTK_VBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_VBOX : StructSignal->Signal = %s\n", StructSignal->Signal);
							g_string_append_printf (VarProto.GstrMain, "// \n");
							break;
						case CLASS_GTK_VIEWPORT :		// class="GtkViewport"
							if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer user_data);", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_VIEWPORT : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_VIEWPORT : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							break;
						case CLASS_GTK_WINDOW :			// class="GtkWindow"
							// PRINT StructClass->Id
							if (NULL != StrClassGtkWindow && 0 != strcmp (StrClassGtkWindow, StructClass->Id)) {
								g_free (StrClassGtkWindow);
								StrClassGtkWindow = NULL;
							}
							if (NULL == StrClassGtkWindow) {
								StrClassGtkWindow = g_strdup (StructClass->Id);
								// g_print ("\t/*\n");
								// g_print ("\t *  StructClass->Id = %s\n", StrClassGtkWindow);
								// g_print ("\t */\n");
								g_string_append_printf (VarProto.GstrMain, "// ---------------------------------------------\n");
								g_string_append_printf (VarProto.GstrMain, "// StructClass->Id = %s\n", StrClassGtkWindow);
								g_string_append_printf (VarProto.GstrMain, "// ---------------------------------------------\n");
							}
							
							if (StructSignal->TypeSignal == SIGNAL_DELETE_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{\n\tgtk_main_quit ();\n\treturn (FALSE);\n}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_DESTROY_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{\n\tgtk_main_quit ();\n\treturn (FALSE);\n}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_EVENT) {
								// g_print ("gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data);\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "gboolean %s (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{return (FALSE);}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_DESTROY) {
								// g_print ("void %s (GtkObject *object, gpointer user_data);\n", StructSignal->Handler);				
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkObject *object, gpointer user_data)\n", StructSignal->Handler);	
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else if (StructSignal->TypeSignal == SIGNAL_REALIZE) {
								// g_print ("void %s (GtkWidget *widget, gpointer   user_data)\n", StructSignal->Handler);	
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "void %s (GtkWidget *widget, gpointer user_data)\n", StructSignal->Handler);
								g_string_append_printf (VarProto.GstrMain, "{}\n");
							} else {
								// g_print ("UNDEFINED : CLASS_GTK_WINDOW : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
								g_string_append_printf (VarProto.GstrMain, "// UNDEFINED : CLASS_GTK_WINDOW : StructSignal->Signal = %s\n", StructSignal->Signal);
								g_string_append_printf (VarProto.GstrMain, "// \n");
							}
							
							break;
					} // END switch
				}
				ListS = g_list_next (ListS);
			}
		}
		
		ListC = g_list_next (ListC);
	}
	if (NULL != StrClassGtkWindow) {
		g_free (StrClassGtkWindow);
		StrClassGtkWindow = NULL;
	}
	g_print ("\n");
}
// 
// TRUE = ok
// FALSE
//	LE FICHIER [ %s ] N'EXISTE PAS
//	ERREUR ALLOCATION DU BUFFER
//	ERREUR A L'OUVERTURE DU FICHIER
gboolean Proto_init (gchar *PathnameFileGlade)
{
// #define NAME_FILE "/home/cat/OTHERS_PROG/BASEBUILD/basebuild-0.0.11/glade/basebuild_copie.glade"
	FILE		*fp = NULL;
	char		*buf = NULL;
	size_t   	Size = libutils_get_size_file (PathnameFileGlade);
	gchar		**Larrbuf = NULL;
	gint		i;
	gboolean	BoolAllocOk = TRUE;
	
	PRINT_FUNC_LF();
	
	// FILE EXIST
	if (FALSE == libutils_test_file_exist (PathnameFileGlade)) {
		g_print ("LE FICHIER [ %s ] N'EXISTE PAS !!!\n", PathnameFileGlade);
		return FALSE;
	}	
	// BUFFER DU FICHIER
	if (NULL == (buf = (char *)malloc (sizeof(char) * (Size + 10)))) {
		g_print ("ERREUR ALLOCATION DU BUFFER !!!\n");
		return FALSE;
	}
	// OUVERTURE DU FICHIER
	if ((fp = fopen (PathnameFileGlade, "r")) == NULL) {
		printf ("\nERREUR A L'OUVERTURE DU FICHIER: %s\n\n", PathnameFileGlade);
		return FALSE;
	}

	// STOCKE LE NOM DU FICHIER POUR ANALYSE
	VarProto.PathNameFileGlade = g_strdup (PathnameFileGlade);

	// LECTURE DU FICHIER DANS: buf
	fread (buf, 1, Size, fp);
	// FERMETURE DU FICHIER
	fclose (fp);
	// BUFFER EN LIGNES POUR: Larrbuf DEPUIS: buf
	Larrbuf = g_strsplit(buf, "\n", 0);
	// REMOVE: buf
	g_free (buf);
	buf = NULL;
	
	// 
	VarProto.GstrTranslate = g_string_new (NULL);
	// 
	build_create_translate_begin ();
	
	// LECTURE DE CHAQUE LIGNE DE: Larrbuf
	for (i=0; Larrbuf[i]; i++) {
		
		if (strstr (Larrbuf[i], "<object class=") ||		// NEW GLADE VERSION
			strstr (Larrbuf[i], "<widget class=")) {	// OLD GLADE VERSION
			// g_print("%s\n", Larrbuf[i]);
			BoolAllocOk = Proto_alloc_object (Larrbuf[i]);
		}
		else if (strstr (Larrbuf[i], "<signal name=")) {
			// g_print("SIGNAL %s\n", Larrbuf[i]);
			BoolAllocOk = Proto_alloc_signal (Larrbuf[i]);
		}
		// 
		// TODO: TRADUCTION
		// 
		else if (strstr (Larrbuf[i], "translatable=")) {
			// g_print("SIGNAL_translatable  %s\n", Larrbuf[i]);
			Proto_alloc_translate (Larrbuf[i]);
		}
		else if (TRUE == VarProto.BoolTranslateOk) {
			Proto_alloc_translate (Larrbuf[i]);
		}
		
		if (FALSE == BoolAllocOk) {
			g_print ("PROBLEME D'ALLOCATION MEMOIRE !!!\n");
			g_print ("\tJE QUITTE LA BOUCLE DE RECHERCHE\n");
			break;
		}
	}

	// 
	Proto_alloc_translate_end ();

	// REMOVE: Larrbuf
	g_strfreev(Larrbuf);
	Larrbuf = NULL;
	
	// Proto_print ();
	Proto_make ();
	
	// g_print ("VarProto.GstrMain = \n%s\n", VarProto.GstrMain->str);
	
	VarProto.BoolOk = TRUE;
	
	return TRUE;
}
// 
// 
void Proto_copy_glade_file (gchar *Src, gchar *Dest)
{
	libutils_copy_src_to_dest (Src, Dest);
}
// 
// 
gboolean Proto_init_is_ok (void)
{
	return (VarProto.BoolOk);
}
// 
// 
GString *Proto_get_buf_main (void)
{
	return (VarProto.GstrMain);
}
// 
// 
GString *Proto_get_buf_translate (void)
{
	return (VarProto.GstrTranslate);
}
// 
// 
gchar *Proto_get_id (void)
{
	GList		*List = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	
	List = g_list_first (ListClass);
	if (NULL != (StructClass = (STRUCT_CLASS *)List->data)) {
		return (StructClass->Id);
	}
	return (NULL);
}

















